@@ -8,8 +8,10 @@ from arraymap import AutoMap
 from arraymap import FrozenAutoMap
 from arraymap import NonUniqueError
 
+
 def test_version():
     import arraymap
+
     assert isinstance(arraymap.__version__, str)
 
 
@@ -41,6 +43,20 @@ def test_fam_contains():
 # ------------------------------------------------------------------------------
 
 
+def test_fam_constructor_a():
+    with pytest.raises(ZeroDivisionError):
+        fam = FrozenAutoMap((x / 0 for x in range(3)))
+
+
+def test_fam_constructor_b():
+    fam1 = FrozenAutoMap(range(3))
+    fam2 = FrozenAutoMap(fam1)
+    assert list(fam2), [0, 1, 2]
+
+
+# ------------------------------------------------------------------------------
+
+
 def test_fam_constructor_array_int_a1():
     a1 = np.array((10, 20, 30), dtype=np.int64)
     with pytest.raises(TypeError):
